import React from 'react';
import Prism from 'prismjs';

function _unsupportedIterableToArray(o, minLen) {
  if (!o) return;
  if (typeof o === "string") return _arrayLikeToArray(o, minLen);
  var n = Object.prototype.toString.call(o).slice(8, -1);
  if (n === "Object" && o.constructor) n = o.constructor.name;
  if (n === "Map" || n === "Set") return Array.from(o);
  if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen);
}

function _arrayLikeToArray(arr, len) {
  if (len == null || len > arr.length) len = arr.length;

  for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i];

  return arr2;
}

function _createForOfIteratorHelperLoose(o, allowArrayLike) {
  var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"];
  if (it) return (it = it.call(o)).next.bind(it);

  if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") {
    if (it) o = it;
    var i = 0;
    return function () {
      if (i >= o.length) return {
        done: true
      };
      return {
        done: false,
        value: o[i++]
      };
    };
  }

  throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}

var InMemoryCache = /*#__PURE__*/function () {
  function InMemoryCache() {
    this._cache = new Map();
  }

  var _proto = InMemoryCache.prototype;

  _proto._generateKey = function _generateKey(blockKey, start, end) {
    return blockKey + "-" + start + "-" + end;
  };

  _proto.setToken = function setToken(blockKey, start, end, token) {
    var cacheKey = this._generateKey(blockKey, start, end);

    this._cache.set(cacheKey, token);
  };

  _proto.getToken = function getToken(blockKey, start, end) {
    var cacheKey = this._generateKey(blockKey, start, end);

    return this._cache.get(cacheKey);
  };

  return InMemoryCache;
}();

var cache = new InMemoryCache();

var defaultFilter = function defaultFilter(block) {
  return block.getType() === "code-block";
};

var defaultGetLanguage = function defaultGetLanguage(block) {
  var language = block.getData().get("language");
  return typeof language !== "string" ? "" : language;
};
/**
 * A function to create a DraftDecorator.
 *
 * usage:
 * ```tsx
 * import { EditorState, CompositeDecorator } from "draft-js";
 * import createPrismDecorator from "draft-js-prism-decorator";
 *
 * const decorators = new CompositeDecorator([createPrismDecorator()]);
 * const editorState = EditorState.createEmpty(decorators);
 * ```
 */


function createPrismDecorator(_temp) {
  var _ref = _temp === void 0 ? {} : _temp,
      _ref$filter = _ref.filter,
      filter = _ref$filter === void 0 ? defaultFilter : _ref$filter,
      _ref$getLanguage = _ref.getLanguage,
      getLanguage = _ref$getLanguage === void 0 ? defaultGetLanguage : _ref$getLanguage;

  var strategy = createStrategy(filter, getLanguage);
  var component = createTokenComponent(getLanguage);
  return {
    strategy: strategy,
    component: component
  };
}

var createStrategy = function createStrategy(filter, getLanguage) {
  return function (contentBlock, callback, contentState) {
    if (!filter(contentBlock, contentState)) return;
    var blockKey = contentBlock.getKey();
    var blockText = contentBlock.getText();
    var language = getLanguage(contentBlock, contentState);
    var tokenList = Prism.tokenize(blockText, Prism.languages[language]);
    var start = 0;
    var end = 0;

    for (var _iterator = _createForOfIteratorHelperLoose(tokenList), _step; !(_step = _iterator()).done;) {
      var token = _step.value;
      end = end + token.length;

      if (typeof token !== "string") {
        cache.setToken(blockKey, start, end, token);
        callback(start, end);
      }

      start = end;
    }
  };
};

var createTokenComponent = function createTokenComponent(getLanguage) {
  return function (props) {
    var _token2, _token3;

    var contentBlock = props.contentState.getBlockForKey(props.blockKey);
    var blockKey = contentBlock.getKey();
    var token = cache.getToken(blockKey, props.start, props.end);
    var classNames = ["token"];

    if (token === undefined) {
      var blockText = contentBlock.getText();
      var language = getLanguage(contentBlock, props.contentState);
      var tokenList = Prism.tokenize(blockText, Prism.languages[language]);
      var start = 0;
      var end = 0;

      for (var _iterator2 = _createForOfIteratorHelperLoose(tokenList), _step2; !(_step2 = _iterator2()).done;) {
        var _token = _step2.value;
        end = end + _token.length;

        if (typeof _token !== "string") {
          if (start === props.start && end === props.end) {
            token = _token;
            break;
          }
        }

        start = end;
      }
    }

    ((_token2 = token) == null ? void 0 : _token2.type) && classNames.push(token.type);

    if ((_token3 = token) != null && _token3.alias) {
      if (Array.isArray(token.alias)) {
        classNames.push.apply(classNames, token.alias);
      } else {
        classNames.push(token.alias);
      }
    }

    return React.createElement("span", {
      className: classNames.join(" "),
      "data-offset-key": props.offsetKey
    }, props.children);
  };
};

export default createPrismDecorator;
//# sourceMappingURL=index.module.js.map
